@@ -1,7 +1,7 @@
 package Yukki::Model::File;
-$Yukki::Model::File::VERSION = '0.991_003'; # TRIAL
+$Yukki::Model::File::VERSION = '0.991_004'; # TRIAL
 
-$Yukki::Model::File::VERSION = '0.991003';use v5.24;
+$Yukki::Model::File::VERSION = '0.991004';use v5.24;
 use utf8;
 use Moo;
 
@@ -49,6 +49,7 @@ has repository => (
         'commit_tree'         => 'commit_tree',
         'update_root'         => 'update_root',
         'find_path'           => 'find_path',
+        'fetch_date'          => 'fetch_date',
         'fetch_size'          => 'fetch_size',
         'repository_name'     => 'name',
         'author_name'         => 'author_name',
@@ -59,6 +60,15 @@ has repository => (
 );
 
 
+has revision => (
+    is          => 'ro',
+    isa         => Str,
+    required    => 1,
+    default     => 'HEAD',
+);
+
+
+
 sub BUILDARGS {
     my $class = shift;
 
@@ -110,7 +120,7 @@ sub file_id {
 
 sub object_id {
     my $self = shift;
-    return $self->find_path($self->full_path);
+    return $self->find_path($self->full_path, $self->revision);
 }
 
 
@@ -138,9 +148,15 @@ sub title {
 }
 
 
+sub file_date {
+    my ($self, $format) = @_;
+    return $self->fetch_date($self->full_path, $self->revision, $format);
+}
+
+
 sub file_size {
     my $self = shift;
-    return $self->fetch_size($self->full_path);
+    return $self->fetch_size($self->full_path, $self->revision);
 }
 
 
@@ -247,7 +263,7 @@ sub exists {
     my $self = shift;
 
     my $path = $self->full_path;
-    return $self->find_path($path);
+    return $self->find_path($path, $self->revision);
 }
 
 
@@ -255,7 +271,7 @@ sub fetch {
     my $self = shift;
 
     my $path = $self->full_path;
-    my $object_id = $self->find_path($path);
+    my $object_id = $self->find_path($path, $self->revision);
 
     return unless defined $object_id;
 
@@ -322,7 +338,7 @@ sub file_preview {
 
 sub list_files {
     my ($self) = @_;
-    return $self->repository->list_files($self->path);
+    return $self->repository->list_files($self->path, $self->revision);
 }
 
 
@@ -355,7 +371,7 @@ Yukki::Model::File - the model for loading and saving files in the wiki
 
 =head1 VERSION
 
-version 0.991_003
+version 0.991_004
 
 =head1 SYNOPSIS
 
@@ -388,6 +404,12 @@ The suffix of the file. Defaults to "yukki".
 This is the the L<Yukki::Model::Repository> the file will be fetched from or
 stored into.
 
+=head2 revision
+
+Defaults to C<HEAD>, which is a synthetic version meaning "whatever is the latest revision." If not set to "HEAD", it is assumed to be a reference to a particular revision.
+
+Setting this to a revision allows historical versions of the file to be fetched.
+
 =head1 METHODS
 
 =head2 BUILDARGS
@@ -415,6 +437,10 @@ This is the git object ID of the file blob.
 
 This is the title for the file. For most files this is the file name. For files with the "yukki" L</filetype>, the title metadata or first heading found in the file is used.
 
+=head2 file_date
+
+This is the date the file was lasted modified in seconds since the epoch.
+
 =head2 file_size
 
 This is the size of the file in bytes.
