@@ -1,7 +1,7 @@
 package Yukki::Model::Repository;
-$Yukki::Model::Repository::VERSION = '0.991_003'; # TRIAL
+$Yukki::Model::Repository::VERSION = '0.991_004'; # TRIAL
 
-$Yukki::Model::Repository::VERSION = '0.991003';use v5.24;
+$Yukki::Model::Repository::VERSION = '0.991004';use v5.24;
 use utf8;
 use Moo;
 
@@ -98,6 +98,14 @@ sub _build_git {
 }
 
 
+sub resolve_ref {
+    my ($self, $ref) = @_;
+    return $self->branch unless defined $ref;
+    return $self->branch if $ref eq 'HEAD';
+    return $ref;
+}
+
+
 sub repository_exists {
     my $self = shift;
     return $self->repository_path->exists;
@@ -280,7 +288,7 @@ sub commit_tree {
 
     return $self->git->run(
         'commit-tree', $new_tree_id, '-p', $old_tree_id, {
-            input => $comment,
+            input => $comment // '',
             env   => {
                 GIT_AUTHOR_NAME  => $self->author_name,
                 GIT_AUTHOR_EMAIL => $self->author_email,
@@ -297,19 +305,20 @@ sub update_root {
 
 
 sub find_path {
-    my ($self, $path) = @_;
+    my ($self, $path, $r) = @_;
+    $r = $self->resolve_ref($r);
 
     my $object_id;
     my @files;
     try {
-        @files = $self->git->run('ls-tree', $self->branch, $path);
+        @files = $self->git->run('ls-tree', $r, $path);
     }
     catch {
 
         # Looks like an empty repo, try initializing it
         if ($_ =~ /Not a valid object name/) {
             $self->initialize_repository;
-            @files = $self->git->run('ls-tree', $self->branch, $path);
+            @files = $self->git->run('ls-tree', $r, $path);
         }
 
         # I don't know what this is, die die die!
@@ -337,10 +346,20 @@ sub show {
 }
 
 
-sub fetch_size {
-    my ($self, $path) = @_;
+sub fetch_date {
+    my ($self, $path, $r, $format) = @_;
+    $r = $self->resolve_ref($r);
+    $format //= 'format:%s';
 
-    my @files = $self->git->run('ls-tree', '-l', $self->branch, $path);
+    return $self->git->run('log', "--date=$format", '-1', '--format=%ad', $r, '--', $path);
+}
+
+
+sub fetch_size {
+    my ($self, $path, $r) = @_;
+    $r = $self->resolve_ref($r);
+
+    my @files = $self->git->run('ls-tree', '-l', $r, $path);
     FILE: for my $line (@files) {
         my ($mode, $type, $id, $size, $name) = split /\s+/, $line, 5;
         return $size if $name eq $path;
@@ -351,10 +370,11 @@ sub fetch_size {
 
 
 sub list_files {
-    my ($self, $path) = @_;
+    my ($self, $path, $r) = @_;
+    $r = $self->resolve_ref($r);
     my @files;
 
-    my @tree_files = $self->git->run('ls-tree', $self->branch, $path . '/');
+    my @tree_files = $self->git->run('ls-tree', $r, $path . '/');
     FILE: for my $line (@tree_files) {
         my ($mode, $type, $id, $name) = split /\s+/, $line, 4;
 
@@ -395,10 +415,11 @@ sub default_file {
 
 
 sub log {
-    my ($self, $full_path) = @_;
+    my ($self, $full_path, $r) = @_;
+    $r = $self->resolve_ref($r);
 
     my @lines = $self->git->run(
-        'log', $self->branch, '--pretty=format:%H~%an~%aD~%ar~%s', '--numstat',
+        'log', $r, '--pretty=format:%H~%an~%aD~%ar~%s', '--numstat',
         '--', $full_path
     );
 
@@ -577,6 +598,13 @@ sub update_remote_config {
     return;
 }
 
+
+sub fetch_remote {
+    my ($self, $name) = @_;
+    $self->git->run('fetch', $name);
+    return;
+}
+
 1;
 
 __END__
@@ -591,7 +619,7 @@ Yukki::Model::Repository - model for accessing objects in a git repository
 
 =head1 VERSION
 
-version 0.991_003
+version 0.991_004
 
 =head1 SYNOPSIS
 
@@ -637,6 +665,12 @@ This is a L<Git::Repository> object which helps us do the real work.
 
 =head1 METHODS
 
+=head2 resolve_ref
+
+    my $r = $self->resolve_ref($ref);
+
+Returns the reference to use for looking up information based on C<$r>. If C<$r> is undefined or set to "HEAD", this will default to using the current C<branch>. Otherwise, C<$ref> is used as-is.
+
 =head2 repository_exists
 
 Checks to see if the git repository is present at all.
@@ -743,11 +777,18 @@ blob at that path for the L</branch>.
 
 Returns the contents of the blob for the given object ID.
 
+=head2 fetch_date
+
+    my $date = $repository->fetch_date($path, $r);
+
+Returns the modification date for the file as of the given revision (or use the
+latest revision if no revision is named).
+
 =head2 fetch_size
 
   my $bytes = $repository->fetch_size($path);
 
-Returns the size, in bites, of the blob at the given path.
+Returns the size, in bytes, of the blob at the given path.
 
 =head2 list_files
 
@@ -865,6 +906,12 @@ Deletes a remote repository from the configuration.
 
 Updates the URL associated with a remote configuration.
 
+=head2 fetch_remote
+
+    $repository->fetch_remote($origin);
+
+Fetches the refs for the remote repository named C<$origin>.
+
 =head1 AUTHOR
 
 Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
