@@ -1,7 +1,7 @@
 package Yukki::Web::Controller::Page;
-$Yukki::Web::Controller::Page::VERSION = '0.991_003'; # TRIAL
+$Yukki::Web::Controller::Page::VERSION = '0.991_004'; # TRIAL
 
-$Yukki::Web::Controller::Page::VERSION = '0.991003';use v5.24;
+$Yukki::Web::Controller::Page::VERSION = '0.991004';use v5.24;
 use utf8;
 use Moo;
 
@@ -57,7 +57,8 @@ sub repo_name_and_path {
 
 
 sub lookup_page {
-    my ($self, $repo_name, $page) = @_;
+    my ($self, $repo_name, $page, $r) = @_;
+    $r ||= 'HEAD';
 
     my $repository = $self->model('Repository', { name => $repo_name });
 
@@ -68,7 +69,7 @@ sub lookup_page {
     }
 
     my $path = join '/', @$page, $final_part;
-    return $repository->file({ path => $path, filetype => $filetype });
+    return $repository->file({ path => $path, filetype => $filetype, revision => $r });
 }
 
 
@@ -77,7 +78,8 @@ sub view_page {
 
     my ($repo_name, $path) = $self->repo_name_and_path($ctx);
 
-    my $page    = $self->lookup_page($repo_name, $path);
+    my $r    = $ctx->request->query_parameters->{r};
+    my $page = $self->lookup_page($repo_name, $path, $r);
 
     my $breadcrumb = $self->breadcrumb($page->repository, $path);
 
@@ -119,7 +121,7 @@ validation_spec edit_page => [
         into => '+',
     ],
     comment => [
-        required => 1,
+        optional => 1,
     ],
 ];
 
@@ -157,11 +159,11 @@ sub edit_page {
 
         else {
             my @errors;
-            push @errors, "Comment is required."
+            push @errors, "comment is required"
                 if $err->{comment};
-            push @errors, "Please try again."
+            push @errors, "please try again"
                 if $err->{yukkitext_position};
-            push @errors, "Wiki content is required."
+            push @errors, "wiki content is required"
                 if $err->{yukkitext};
 
             $ctx->add_errors(@errors);
@@ -285,13 +287,22 @@ sub view_history {
 
     my $breadcrumb = $self->breadcrumb($page->repository, $path);
 
+    my $page_url = $ctx->rebase_url(
+        join('/', 'page/view', $repo_name, $page->full_path),
+    );
+
     $ctx->response->body(
         $self->view('Page')->history($ctx, {
             title      => $page->title,
             breadcrumb => $breadcrumb,
             repository => $repo_name,
             page       => $page->full_path,
-            revisions  => [ $page->history ],
+            revisions  => [ map {
+                +{
+                    page_url => "$page_url?r=".$_->{object_id},
+                    file     => $_,
+                }
+            } $page->history ],
         })
     );
 }
@@ -431,7 +442,7 @@ Yukki::Web::Controller::Page - controller for viewing and editing pages
 
 =head1 VERSION
 
-version 0.991_003
+version 0.991_004
 
 =head1 DESCRIPTION
 
