@@ -1,7 +1,7 @@
 package Yukki::Web::Plugin::YukkiText;
-$Yukki::Web::Plugin::YukkiText::VERSION = '0.991_003'; # TRIAL
+$Yukki::Web::Plugin::YukkiText::VERSION = '0.991_004'; # TRIAL
 
-$Yukki::Web::Plugin::YukkiText::VERSION = '0.991003';use v5.24;
+$Yukki::Web::Plugin::YukkiText::VERSION = '0.991004';use v5.24;
 use utf8;
 use Moo;
 
@@ -137,7 +137,7 @@ sub yukkitext {
     my $file       = $params->{file};
     my $position   = 0 + ($params->{position} // -1);
     my $repository = $file->repository_name;
-    my $yukkitext  = $file->fetch;
+    my $yukkitext  = $file->fetch // '';
 
     $yukkitext =~ s[(.{$position}.*?)$][$1<span id="yukkitext-caret"></span>]sm
         if $position >= 0;
@@ -234,7 +234,7 @@ Yukki::Web::Plugin::YukkiText - format text/yukki files using markdown, etc.
 
 =head1 VERSION
 
-version 0.991_003
+version 0.991_004
 
 =head1 SYNOPSIS
 
