@@ -1,7 +1,7 @@
 package Yukki::Web::View::Page;
-$Yukki::Web::View::Page::VERSION = '0.991_003'; # TRIAL
+$Yukki::Web::View::Page::VERSION = '0.991_004'; # TRIAL
 
-$Yukki::Web::View::Page::VERSION = '0.991003';use v5.24;
+$Yukki::Web::View::Page::VERSION = '0.991004';use v5.24;
 use utf8;
 use Moo;
 
@@ -46,6 +46,8 @@ sub _build_view_template {
         template   => 'page/view.html',
         directives => [
             '#yukkitext' => 'html | encoded_string',
+            '#revision'  => 'revision',
+            '#file_date' => 'file_date',
         ],
     );
 }
@@ -64,24 +66,20 @@ sub _build_history_template {
             'form@action' => 'form_action',
             '.revision'   => {
                 'rev<-revisions' => [
-                    '.first-revision input@value'  => 'rev.object_id',
-                    '.second-revision input@value' => 'rev.object_id',
-                    '.date'                        => 'rev.time_ago',
-                    '.author'                      => 'rev.author_name',
-                    '.diffstat'                    => '+={rev.lines_added}/-={rev.lines_removed}',
-                    '.comment'                     => 'rev.comment | default("(no comment)")',
-                    '.first-revision input'        => sub {
-                        my ($t, $input, $vars) = @_;
-                        $input->attr(checked => 'checked')
-                            if $vars->{index} == 2;
-                    },
-                    '.second-revision input'       => sub {
-                        my ($t, $input, $vars) = @_;
-                        $input->attr(checked => 'checked')
-                            if $vars->{index} == 1;
-                    },
+                    '.first-revision input@value'  => 'rev.file.object_id',
+                    '.second-revision input@value' => 'rev.file.object_id',
+                    '.date a'                        => 'rev.file.time_ago',
+                    '.date a@href'                 => '={rev.page_url}',
+                    '.author'                      => 'rev.file.author_name',
+                    '.diffstat'                    => '+={rev.file.lines_added}/-={rev.file.lines_removed}',
+                    '.comment'                     => 'rev.file.comment | default("(no comment)")',
                 ],
             },
+            sub {
+                my ($t, $dom, $data) = @_;
+                $dom->at('.revision:nth-child(2) .first-revision input')->attr(checked => 1);
+                $dom->at('.revision:nth-child(1) .second-revision input')->attr(checked => 1);
+            },
         ],
     );
 }
@@ -242,11 +240,21 @@ sub view {
 
     $self->page_navigation($ctx->response, 'view', $vars);
 
+    $ctx->add_info("This is a historical version of this page")
+        if $file->revision ne 'HEAD'
+           and $file->find_path($file->full_path)
+                ne $file->object_id;
+
+    my $rev8 = $file->revision;
+    $rev8 = substr $rev8, 0, 8 if $file->revision ne 'HEAD';
+
     return $self->render_page(
         template => $self->view_template,
         context  => $ctx,
         vars     => {
-            'html' => $html,
+            'html'      => $html,
+            'revision'  => $rev8,
+            'file_date' => $file->file_date('relative'),
         },
     );
 }
@@ -464,7 +472,7 @@ Yukki::Web::View::Page - render HTML for viewing and editing wiki pages
 
 =head1 VERSION
 
-version 0.991_003
+version 0.991_004
 
 =head1 DESCRIPTION
 
