@@ -32,14 +32,89 @@ function updatePosition() {
     }
 }
 
+function handleAnyAndNoneTagPlaceholders(field, editor, tags) {
+    $('li', editor).each(function() {
+        var $li = $(this);
+        if ($li.find('.tag-editor-tag').html() == 'NONE') {
+            $li.addClass('NONE-group');
+            $li.removeClass('ANY-group');
+            $li.removeClass('plain-group');
+        }
+        else if ($li.find('.tag-editor-tag').html() == 'ANY') {
+            $li.addClass('ANY-group');
+            $li.removeClass('NONE-group');
+            $li.removeClass('plain-group');
+        }
+        else {
+            $li.addClass('plain-group');
+            $li.removeClass('ANY-group');
+            $li.removeClass('NONE-group');
+        }
+    });
+}
+
 $(document).ready(function() {
     $(':button,.button').button();
 
+    $('input.group-tags').tagEditor({ 
+        delimiter: ' ',
+        forceLowercase: false
+    });
+
+    $('input.all-group-tags').tagEditor({ 
+        delimiter: ' ',
+        forceLowercase: false,
+        onChange: handleAnyAndNoneTagPlaceholders
+    });
+
+    $('ul.tag-editor').each(function () {
+        handleAnyAndNoneTagPlaceholders(null, this, null);
+    });
+
     $('#preview-yukkitext').scrollTop('#yukkitext-caret');
 
     $('every_10s', updatePosition);
     $('form.edit-page').submit(updatePosition);
 
+    $('.popup-menu').each(function () {
+        var $menu = $(this);
+        var toggle = '#' + $menu.attr('data-toggle');
+
+        // Open popup menu on toggle click
+        $(toggle).click(function(evt) {
+            evt.preventDefault();
+            $menu.toggle();
+            $menu.position({ of: toggle, my: 'left top', at: 'left bottom' });
+        });
+    });
+
+    // Close any open popup menu on click outside of any popup
+    $('body').click(function(evt) {
+        var $target = $(evt.target);
+        $('.popup-menu').each(function () {
+            var $popup = $(this);
+            var inPopup = $target.closest($popup).length != 0;
+            var inToggle = $target.closest('#' + $popup.attr('data-toggle')).length != 0;
+            if (!inPopup && !inToggle) $popup.hide();
+        });
+    });
+
+    $('form.double-confirm').submit(function(evt) {
+        var yes = window.confirm("Are you really sure? This action cannot be undone.");
+        if (!yes) {
+            evt.preventDefault();
+        }
+    });
+
+    $('#show-kill').click(function (evt) {
+        if ($(this).is(':checked')) {
+            $('.kill-action').show();
+        }
+        else {
+            $('.kill-action').hide();
+        }
+    });
+
     if ($('#preview-yukkitext').length > 0) {
         $(window).bind('every_10s', function() {
             var url = String(window.location).replace(/\/edit\//, '/preview/');
@@ -78,8 +153,6 @@ $(document).ready(function() {
     $('input[name="r1"]').on('click', 'body', function() { show_hide_revision_checkbox('r2', $(this).val()) });
     $('input[name="r2"]').on('click', 'body', function() { show_hide_revision_checkbox('r1', $(this).val()) });
 
-    $('#user-groups').tagEditor({ delimiter: ' ' });
-
     $('.attachments').each(function() {
         var $this = $(this);
 
